pub enum PluginRegisterFunctionError {
AlreadyExists(String),
}Expand description
Errors that can occur when registering a function in a plugin.
This error type is returned when attempting to register a function in a plugin’s registry.
Variants