pub enum RegisterManagerError {
AlreadyOccupiedFormat(String),
RegisterManagerByManager(Box<dyn StdError + Send + Sync>),
}Expand description
Errors that can occur when registering a plugin manager.
This error type is returned by manager registration operations.
Variants
AlreadyOccupiedFormat(String)
A manager with the same format is already registered
RegisterManagerByManager(Box<dyn StdError + Send + Sync>)
The manager itself returned an error during registration