pub enum RegisterRequestError {
NotFound,
ArgumentsIncorrectly,
}Expand description
Errors that can occur when registering a function request in a plugin.
This error type is returned when validating and registering function requests.
Variants
NotFound
The requested function was not found
ArgumentsIncorrectly
The function arguments are incorrectly specified