pub enum UnregisterManagerError {
NotFound,
UnregisterPlugin(UnregisterPluginError),
UnregisterManagerByManager(Box<dyn StdError + Send + Sync>),
}Expand description
Errors that can occur when unregistering a plugin manager.
This error type is returned by manager unregistration operations.
Variants
NotFound
The manager was not found
UnregisterPlugin(UnregisterPluginError)
Failed to unregister a plugin during manager unregistration
UnregisterManagerByManager(Box<dyn StdError + Send + Sync>)
The manager itself returned an error during unregistration