pub struct ParseVariableError { /* private fields */ }Expand description
Error that occurs when parsing a Variable into a specific type.
This error is returned when attempting to convert a Variable to a specific Rust type, but the conversion fails due to a type mismatch.
Implementations